@@ -4,19 +4,18 @@
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,24 +32,38 @@
 #include "makepath.h"
 #include "strbuf.h"
 
-/*
+/**
+ * @details
  * makepath: make path from directory and file.
  *
- *	i)	dir	directory(optional)
- *	i)	file	file
- *	i)	suffix	suffix(optional)
- *	r)		path
+ *	@param[in]	dir	directory(optional), @CODE{NULL} if not used.
+ *	@param[in]	file	file
+ *	@param[in]	suffix	suffix(optional), @CODE{NULL} if not used.
+ *	@return		path
  *
- * It is necessary to note the usage of makepath(), because it returns
- * module local area. If makepath() is called again in the function which
- * is passed the return value of makepath(), then the value is overwritten.
+ * @note Only makes a name, no real directories or files are created.
+ *
+ * The path in argument @a dir can be an absoulute or relative one (@EMPH{Not sure if
+ * can be relative one on WIN32}). <br>
+ * A @CODE{'.'} (dot) will be added to the @a suffix (file extension) argument, 
+ * if not already present. Any existing suffix within @a file will not be removed. <br>
+ * A separator (@CODE{'/'} or @CODE{'\\'}) will be added to @a dir, if not present,
+ * then @a file is appended to the end of @a dir. @a file and @a dir are used as
+ * given. None of the paths given or generated are checked for validity, but they
+ * are checked for size (#MAXPATHLEN), (calls die() if too big).
+ *
+ * @attention
+ * It is necessary to note the usage of @NAME{makepath()}, because it returns
+ * module local area. If @NAME{makepath()} is called again in the function which
+ * is passed the return value of @NAME{makepath()}, then the value is overwritten. <br>
  * This may cause the bug which is not understood easily.
  * You must not pass the return value except for the safe functions
  * described below.
  * 
+ * @attention
  * Here are safe functions.
- * o functions in standard C library.
- * o following libutil functions:
+ * - functions in standard C library.
+ * - following libutil functions: <br>
  *   test(), dbop_open(), strlimcpy(), strbuf_puts(), die()
  */
 const char *
